==> arquillian-protocol-jmx-1.1.0.Final-test-sources.jar: org/jboss/arquillian/protocol/jmx/test/TestCommandCallback.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.protocol.jmx.test;

import org.jboss.arquillian.container.test.spi.command.Command;
import org.jboss.arquillian.container.test.spi.command.CommandCallback;

/**
 * TestRemoteCommandCallback
 * 
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class TestCommandCallback implements CommandCallback
{
   private Object[] results;
   
   private int invocationCount = 0;

   public TestCommandCallback(Object... object)
   {
      results = object;
   }
   
   @SuppressWarnings({"rawtypes", "unchecked"})
   @Override
   public void fired(Command event)
   {
      event.setResult(results[invocationCount++]);
   }
}

==> arquillian-protocol-jmx-1.9.2.Final-test-sources.jar: org/jboss/arquillian/protocol/jmx/test/TestCommandCallback.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.protocol.jmx.test;

import org.jboss.arquillian.container.test.spi.command.Command;
import org.jboss.arquillian.container.test.spi.command.CommandCallback;

/**
 * TestRemoteCommandCallback
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class TestCommandCallback implements CommandCallback {
    private Object[] results;

    private int invocationCount = 0;

    public TestCommandCallback(Object... object) {
        results = object;
    }

    @SuppressWarnings({"rawtypes", "unchecked"})
    @Override
    public void fired(Command event) {
        event.setResult(results[invocationCount++]);
    }
}
